@@ -54,6 +54,7 @@ import qualified Data.Set as S
 
 import Annex.Common
 import Logs.Location
+import Types.Transfer
 import Logs.Transfer
 import qualified Git
 import qualified Annex
@@ -267,8 +268,8 @@ lockContentUsing locker key a = do
 		(unlock lockfile)
 		(const a)
   where
-	alreadylocked = error "content is locked"
-	failedtolock e = error $ "failed to lock content: " ++ show e
+	alreadylocked = giveup "content is locked"
+	failedtolock e = giveup $ "failed to lock content: " ++ show e
 
 	lock contentfile lockfile =
 		(maybe alreadylocked return 
@@ -901,7 +902,7 @@ saveState nocommit = doSideAction $ do
 
 {- Downloads content from any of a list of urls. -}
 downloadUrl :: Key -> MeterUpdate -> [Url.URLString] -> FilePath -> Annex Bool
-downloadUrl k p urls file = concurrentMeteredFile file (Just p) k $
+downloadUrl k p urls file = meteredFile file (Just p) k $
 	go =<< annexWebDownloadCommand <$> Annex.getGitConfig
   where
 	go Nothing = do
