@@ -20,7 +20,9 @@ module Annex.LockPool.PosixOrPid (
 	checkSaneLock,
 ) where
 
-import Common.Annex
+import Common
+import Types
+import Annex.Locations
 import qualified Annex
 import qualified Utility.LockPool.Posix as Posix
 import qualified Utility.LockPool.PidLock as Pid
@@ -45,8 +47,14 @@ tryLockExclusive :: Maybe FileMode -> LockFile -> Annex (Maybe LockHandle)
 tryLockExclusive m f = tryPidLock m f $ Posix.tryLockExclusive m f
 
 checkLocked :: LockFile -> Annex (Maybe Bool)
-checkLocked f = Posix.checkLocked f
-	`pidLockCheck` Pid.checkLocked
+checkLocked f = Posix.checkLocked f `pidLockCheck` checkpid
+  where
+	checkpid pidlock = do
+		v <- Pid.checkLocked pidlock
+		case v of
+			-- Only return true when the posix lock file exists.
+			Just _ -> Posix.checkLocked f
+			Nothing -> return Nothing
 
 getLockStatus :: LockFile -> Annex LockStatus
 getLockStatus f = Posix.getLockStatus f
@@ -58,7 +66,7 @@ checkSaneLock f h = H.checkSaneLock f h
 
 pidLockFile :: Annex (Maybe FilePath)
 pidLockFile = ifM (annexPidLock <$> Annex.getGitConfig)
-	( Just <$> fromRepo gitAnnexPidLockFile
+	( Just <$> Annex.fromRepo gitAnnexPidLockFile
 	, pure Nothing
 	)
 
@@ -86,6 +94,6 @@ tryPidLock m f posixlock = liftIO . go =<< pidLockFile
 
 -- The posix lock file is created even when using pid locks, in order to
 -- avoid complicating any code that might expect to be able to see that
--- lock file.
+-- lock file. But, it's not locked.
 dummyPosixLock :: Maybe FileMode -> LockFile -> IO ()
 dummyPosixLock m f = closeFd =<< openLockFile ReadLock m f
