@@ -13,12 +13,11 @@ import Types.Remote (RemoteConfig, RemoteConfigKey, typename, setup)
 import Logs.Remote
 import Logs.Trust
 import qualified Git.Config
+import Git.Types (RemoteName)
 
 import qualified Data.Map as M
 import Data.Ord
 
-type RemoteName = String
-
 {- See if there's an existing special remote with this name.
  -
  - Prefer remotes that are not dead when a name appears multiple times. -}
