@@ -21,6 +21,7 @@ import Types.Messages
 import Types.Command
 import Types.DeferredParse
 import Types.DesktopNotify
+import Types.Concurrency
 import qualified Annex
 import qualified Remote
 import qualified Limit
@@ -139,27 +140,37 @@ parseToOption = parseRemoteOption $ strOption
 data KeyOptions
 	= WantAllKeys
 	| WantUnusedKeys
+	| WantFailedTransfers
 	| WantSpecificKey Key
 	| WantIncompleteKeys
+	| WantBranchKeys [Branch]
 
-parseKeyOptions :: Bool -> Parser KeyOptions
-parseKeyOptions allowincomplete = if allowincomplete
-	then base
-		<|> flag' WantIncompleteKeys
-			( long "incomplete"
-			<> help "resume previous downloads"
-			)
-	else base
-  where
-	base = parseAllOption
-		<|> flag' WantUnusedKeys
-			( long "unused" <> short 'U'
-			<> help "operate on files found by last run of git-annex unused"
-			)
-		<|> (WantSpecificKey <$> option (str >>= parseKey)
-			( long "key" <> metavar paramKey
-			<> help "operate on specified key"
-			))
+parseKeyOptions :: Parser KeyOptions
+parseKeyOptions = parseAllOption
+	<|> WantBranchKeys <$> some (option (str >>= pure . Ref)
+		( long "branch" <> metavar paramRef
+		<> help "operate on files in the specified branch or treeish"
+		))
+	<|> flag' WantUnusedKeys
+		( long "unused" <> short 'U'
+		<> help "operate on files found by last run of git-annex unused"
+		)
+	<|> (WantSpecificKey <$> option (str >>= parseKey)
+		( long "key" <> metavar paramKey
+		<> help "operate on specified key"
+		))
+
+parseFailedTransfersOption :: Parser KeyOptions
+parseFailedTransfersOption = flag' WantFailedTransfers
+	( long "failed"
+	<> help "operate on files that recently failed to be transferred"
+	)
+
+parseIncompleteOption :: Parser KeyOptions
+parseIncompleteOption = flag' WantIncompleteKeys
+	( long "incomplete"
+	<> help "resume previous downloads"
+	)
 
 parseAllOption :: Parser KeyOptions
 parseAllOption = flag' WantAllKeys
@@ -275,12 +286,19 @@ combiningOptions =
 	shortopt o h = globalFlag (Limit.addToken [o]) ( short o <> help h <> hidden )
 
 jsonOption :: GlobalOption
-jsonOption = globalFlag (Annex.setOutput JSONOutput)
+jsonOption = globalFlag (Annex.setOutput (JSONOutput False))
 	( long "json" <> short 'j'
 	<> help "enable JSON output"
 	<> hidden
 	)
 
+jsonProgressOption :: GlobalOption
+jsonProgressOption = globalFlag (Annex.setOutput (JSONOutput True))
+	( long "json-progress" <> short 'j'
+	<> help "include progress in JSON output"
+	<> hidden
+	)
+
 -- Note that a command that adds this option should wrap its seek
 -- action in `allowConcurrentOutput`.
 jobsOption :: GlobalOption
@@ -292,7 +310,7 @@ jobsOption = globalSetter set $
 		)
   where
 	set n = do
-		Annex.changeState $ \s -> s { Annex.concurrentjobs = Just n }
+		Annex.changeState $ \s -> s { Annex.concurrency = Concurrent n }
 		c <- liftIO getNumCapabilities
 		when (n > c) $
 			liftIO $ setNumCapabilities n
