@@ -16,7 +16,7 @@ import Annex.Wanted
 import qualified Command.Move
 
 cmd :: Command
-cmd = withGlobalOptions (jobsOption : jsonOption : annexedMatchingOptions) $ 
+cmd = withGlobalOptions (jobsOption : jsonOption : jsonProgressOption : annexedMatchingOptions) $ 
 	command "get" SectionCommon 
 		"make content of annexed files available"
 		paramPaths (seek <$$> optParser)
@@ -34,7 +34,7 @@ optParser desc = GetOptions
 	<$> cmdParams desc
 	<*> optional parseFromOption
 	<*> parseAutoOption
-	<*> optional (parseKeyOptions True)
+	<*> optional (parseIncompleteOption <|> parseKeyOptions <|> parseFailedTransfersOption)
 	<*> parseBatchOption
 
 seek :: GetOptions -> CommandSeek
@@ -49,17 +49,19 @@ seek o = allowConcurrentOutput $ do
 			(getFiles o)
 
 start :: GetOptions -> Maybe Remote -> FilePath -> Key -> CommandStart
-start o from file key = start' expensivecheck from key (Just file)
+start o from file key = start' expensivecheck from key afile (mkActionItem afile)
   where
+	afile = Just file
 	expensivecheck
 		| autoMode o = numCopiesCheck file key (<) <||> wantGet False (Just key) (Just file)
 		| otherwise = return True
 
-startKeys :: Maybe Remote -> Key -> CommandStart
-startKeys from key = start' (return True) from key Nothing
+startKeys :: Maybe Remote -> Key -> ActionItem -> CommandStart
+startKeys from key ai = checkFailedTransferDirection ai Download $
+	start' (return True) from key Nothing ai
 
-start' :: Annex Bool -> Maybe Remote -> Key -> AssociatedFile -> CommandStart
-start' expensivecheck from key afile = stopUnless (not <$> inAnnex key) $
+start' :: Annex Bool -> Maybe Remote -> Key -> AssociatedFile -> ActionItem -> CommandStart
+start' expensivecheck from key afile ai = stopUnless (not <$> inAnnex key) $
 	stopUnless expensivecheck $
 		case from of
 			Nothing -> go $ perform key afile
@@ -68,7 +70,7 @@ start' expensivecheck from key afile = stopUnless (not <$> inAnnex key) $
 					go $ Command.Move.fromPerform src False key afile
   where
 	go a = do
-		showStart' "get" key afile
+		showStart' "get" key ai
 		next a
 
 perform :: Key -> AssociatedFile -> CommandPerform
@@ -87,16 +89,17 @@ getKey' key afile = dispatch
 		showNote "not available"
 		showlocs
 		return False
-	dispatch remotes = notifyTransfer Download afile $ trycopy remotes remotes
-	trycopy full [] _ = do
-		Remote.showTriedRemotes full
-		showlocs
-		return False
-	trycopy full (r:rs) witness =
-		ifM (probablyPresent r)
-			( docopy r witness <||> trycopy full rs witness
-			, trycopy full rs witness
+	dispatch remotes = notifyTransfer Download afile $ \witness -> do
+		ok <- pickRemote remotes $ \r -> ifM (probablyPresent r)
+			( docopy r witness
+			, return False
 			)
+		if ok
+			then return ok
+			else do
+				Remote.showTriedRemotes remotes
+				showlocs
+				return False
 	showlocs = Remote.showLocations False key []
 		"No other repository is known to contain the file."
 	-- This check is to avoid an ugly message if a remote is a
@@ -106,7 +109,7 @@ getKey' key afile = dispatch
 			either (const False) id <$> Remote.hasKey r key
 		| otherwise = return True
 	docopy r witness = getViaTmp (RemoteVerify r) key $ \dest ->
-		download (Remote.uuid r) key afile noRetry noObserver 
+		download (Remote.uuid r) key afile forwardRetry
 			(\p -> do
 				showAction $ "from " ++ Remote.name r
 				Remote.retrieveKeyFile r key afile dest p
