@@ -45,27 +45,27 @@ startNew file key = ifM (isJust <$> isAnnexLink file)
 	)
   where
 	go (Just key')
-		| key' == key = cont True
+		| key' == key = cont
 		| otherwise = errorModified
 	go Nothing = 
 		ifM (isUnmodified key file) 
-			( cont False
+			( cont
 			, ifM (Annex.getState Annex.force)
-				( cont True
+				( cont
 				, errorModified
 				)
 			)
-	cont = next . performNew file key
+	cont = next $ performNew file key
 
-performNew :: FilePath -> Key -> Bool -> CommandPerform
-performNew file key filemodified = do
+performNew :: FilePath -> Key -> CommandPerform
+performNew file key = do
 	lockdown =<< calcRepo (gitAnnexLocation key)
 	addLink file key
 		=<< withTSDelta (liftIO . genInodeCache file)
 	next $ cleanupNew file key
   where
 	lockdown obj = do
-		ifM (catchBoolIO $ sameInodeCache obj =<< Database.Keys.getInodeCaches key)
+		ifM (isUnmodified key obj)
 			( breakhardlink obj
 			, repopulate obj
 			)
@@ -79,24 +79,22 @@ performNew file key filemodified = do
 		unlessM (sameInodeCache obj (maybeToList mfc)) $ do
 			modifyContent obj $ replaceFile obj $ \tmp -> do
 				unlessM (checkedCopyFile key obj tmp Nothing) $
-					error "unable to lock file"
+					giveup "unable to lock file"
 			Database.Keys.storeInodeCaches key [obj]
 
 	-- Try to repopulate obj from an unmodified associated file.
-	repopulate obj
-		| filemodified = modifyContent obj $ do
-			g <- Annex.gitRepo
-			fs <- map (`fromTopFilePath` g)
-				<$> Database.Keys.getAssociatedFiles key
-			mfile <- firstM (isUnmodified key) fs
-			liftIO $ nukeFile obj
-			case mfile of
-				Just unmodified ->
-					unlessM (checkedCopyFile key unmodified obj Nothing)
-						lostcontent
-				Nothing -> lostcontent
-		| otherwise = modifyContent obj $ 
-			liftIO $ renameFile file obj
+	repopulate obj = modifyContent obj $ do
+		g <- Annex.gitRepo
+		fs <- map (`fromTopFilePath` g)
+			<$> Database.Keys.getAssociatedFiles key
+		mfile <- firstM (isUnmodified key) fs
+		liftIO $ nukeFile obj
+		case mfile of
+			Just unmodified ->
+				unlessM (checkedCopyFile key unmodified obj Nothing)
+					lostcontent
+			Nothing -> lostcontent
+
 	lostcontent = logStatus key InfoMissing
 
 cleanupNew :: FilePath -> Key -> CommandCleanup
@@ -117,4 +115,4 @@ performOld file = do
 	next $ return True
 
 errorModified :: a
-errorModified =  error "Locking this file would discard any changes you have made to it. Use 'git annex add' to stage your changes. (Or, use --force to override)"
+errorModified =  giveup "Locking this file would discard any changes you have made to it. Use 'git annex add' to stage your changes. (Or, use --force to override)"
