@@ -7,11 +7,8 @@
 
 module Command.LookupKey where
 
-import Common.Annex
 import Command
-import CmdLine.Batch
 import Annex.CatFile
-import Types.Key
 
 cmd :: Command
 cmd = notBareRepo $ noCommit $ noMessages $
