@@ -31,7 +31,7 @@ data WhereisOptions = WhereisOptions
 optParser :: CmdParamsDesc -> Parser WhereisOptions
 optParser desc = WhereisOptions
 	<$> cmdParams desc
-	<*> optional (parseKeyOptions False)
+	<*> optional parseKeyOptions
 	<*> parseBatchOption
 
 seek :: WhereisOptions -> CommandSeek
@@ -47,14 +47,13 @@ seek o = do
 				(whereisFiles o)
 
 start :: M.Map UUID Remote -> FilePath -> Key -> CommandStart
-start remotemap file key = start' remotemap key (Just file)
+start remotemap file key = startKeys remotemap key (mkActionItem afile)
+  where
+	afile = Just file
 
-startKeys :: M.Map UUID Remote -> Key -> CommandStart
-startKeys remotemap key = start' remotemap key Nothing
-
-start' :: M.Map UUID Remote -> Key -> AssociatedFile -> CommandStart
-start' remotemap key afile = do
-	showStart' "whereis" key afile
+startKeys :: M.Map UUID Remote -> Key -> ActionItem -> CommandStart
+startKeys remotemap key ai = do
+	showStart' "whereis" key ai
 	next $ perform remotemap key
 
 perform :: M.Map UUID Remote -> Key -> CommandPerform
@@ -106,7 +105,6 @@ showRemoteUrls :: M.Map UUID Remote -> (UUID, [URLString]) -> Annex ()
 showRemoteUrls remotemap (uu, us)
 	| null us = noop
 	| otherwise = case M.lookup uu remotemap of
-		Just r -> do
-			let ls = unlines $ map (\u -> name r ++ ": " ++ u) us 
-			outputMessage noop ('\n' : indent ls ++ "\n")
+		Just r -> showLongNote $ 
+			unlines $ map (\u -> name r ++ ": " ++ u) us 
 		Nothing -> noop
