@@ -21,23 +21,19 @@ module Database.Fsck (
 ) where
 
 import Database.Types
-import qualified Database.Handle as H
-import Locations
+import qualified Database.Queue as H
+import Annex.Locations
 import Utility.PosixFiles
 import Utility.Exception
-import Common
-import Annex
-import Types.Key
-import Types.UUID
+import Annex.Common
 import Annex.Perms
 import Annex.LockFile
-import Messages
 
 import Database.Persist.TH
 import Database.Esqueleto hiding (Key)
 import Data.Time.Clock
 
-data FsckHandle = FsckHandle H.DbHandle UUID
+data FsckHandle = FsckHandle H.DbQueue UUID
 
 {- Each key stored in the database has already been fscked as part
  - of the latest incremental fsck pass. -}
@@ -59,7 +55,7 @@ newPass u = isJust <$> tryExclusiveLock (gitAnnexFsckDbLock u) go
 	go = liftIO . void . tryIO . removeDirectoryRecursive
 		=<< fromRepo (gitAnnexFsckDbDir u)
 
-{- Opens the database, creating it atomically if it doesn't exist yet. -}
+{- Opens the database, creating it if it doesn't exist yet. -}
 openDb :: UUID -> Annex FsckHandle
 openDb u = do
 	dbdir <- fromRepo (gitAnnexFsckDbDir u)
@@ -77,16 +73,12 @@ openDb u = do
 			void $ tryIO $ removeDirectoryRecursive dbdir
 			rename tmpdbdir dbdir
 	lockFileCached =<< fromRepo (gitAnnexFsckDbLock u)
-	h <- liftIO $ H.openDb db "fscked"
-
-	-- work around https://github.com/yesodweb/persistent/issues/474
-	liftIO setConsoleEncoding
-
+	h <- liftIO $ H.openDbQueue db "fscked"
 	return $ FsckHandle h u
 
 closeDb :: FsckHandle -> Annex ()
 closeDb (FsckHandle h u) = do
-	liftIO $ H.closeDb h
+	liftIO $ H.closeDbQueue h
 	unlockFile =<< fromRepo (gitAnnexFsckDbLock u)
 
 addDb :: FsckHandle -> Key -> IO ()
@@ -102,8 +94,9 @@ addDb (FsckHandle h _) k = H.queueDb h checkcommit $
 			now <- getCurrentTime
 			return $ diffUTCTime lastcommittime now > 300
 
+{- Doesn't know about keys that were just added with addDb. -}
 inDb :: FsckHandle -> Key -> IO Bool
-inDb (FsckHandle h _) = H.queryDb h . inDb' . toSKey
+inDb (FsckHandle h _) = H.queryDbQueue h . inDb' . toSKey
 
 inDb' :: SKey -> SqlPersistM Bool
 inDb' sk = do
