@@ -14,7 +14,7 @@ module Logs.Activity (
 
 import Data.Time.Clock.POSIX
 
-import Common.Annex
+import Annex.Common
 import qualified Annex.Branch
 import Logs
 import Logs.UUIDBased
