@@ -13,7 +13,7 @@ module Logs.NumCopies (
 	globalNumCopiesLoad,
 ) where
 
-import Common.Annex
+import Annex.Common
 import qualified Annex
 import Types.NumCopies
 import Logs
