@@ -20,7 +20,7 @@ import Messages.Progress
 import Utility.Metered
 import Utility.Rsync
 import Types.Remote
-import Logs.Transfer
+import Types.Transfer
 import Config
 
 {- Generates parameters to ssh to a repository's host and run a command.
@@ -29,7 +29,7 @@ import Config
 toRepo :: Git.Repo -> RemoteGitConfig -> [CommandParam] -> Annex [CommandParam]
 toRepo r gc sshcmd = do
 	let opts = map Param $ remoteAnnexSshOptions gc
-	let host = fromMaybe (error "bad ssh url") $ Git.Url.hostuser r
+	let host = fromMaybe (giveup "bad ssh url") $ Git.Url.hostuser r
 	params <- sshOptions (host, Git.Url.port r) gc opts
 	return $ params ++ Param host : sshcmd
 
